@@ -28,7 +28,8 @@
 #  @author Jeff Green,   ParIT Worker Co-operative <jeff@parit.ca>
 #  @ingroup python_bindings
 
-import gnucash.gnucash_core_c as gnucash_core_c
+from gnucash import gnucash_core_c
+from gnucash import _sw_core_utils
 
 from gnucash.function_class import \
      ClassFromFunctions, extract_attributes_with_prefix, \
@@ -46,6 +47,27 @@ from gnucash.gnucash_core_c import gncInvoiceLookup, gncInvoiceGetInvoiceFromTxn
     gnc_numeric_create, double_to_gnc_numeric, string_to_gnc_numeric, \
     gnc_numeric_to_string
 
+try:
+    import gettext
+
+    _localedir = _sw_core_utils.gnc_path_get_localedir()
+    gettext.install(_sw_core_utils.GETTEXT_PACKAGE, _localedir)
+except:
+    print()
+    print("Problem importing gettext!")
+    import traceback
+    import sys
+    exc_type, exc_value, exc_traceback = sys.exc_info()
+    traceback.print_exception(exc_type, exc_value, exc_traceback)
+    print()
+
+    def _(s):
+        """Null translator function, gettext not available"""
+        return s
+
+    import builtins
+    builtins.__dict__['_'] = _
+
 class GnuCashCoreClass(ClassFromFunctions):
     _module = gnucash_core_c
 
@@ -75,7 +97,7 @@ class Session(GnuCashCoreClass):
     """
 
     def __init__(self, book_uri=None, ignore_lock=False, is_new=False,
-                 force_new= False):
+                 force_new=False, instance=None):
         """A convenient constructor that allows you to specify a book URI,
         begin the session, and load the book.
 
@@ -95,13 +117,15 @@ class Session(GnuCashCoreClass):
         ignore_lock is passed to qof_session_begin's argument of the
         same name and is used to break an existing lock on a dataset.
 
+        instance argument can be passed if new Session is used as a
+        wrapper for an existing session instance
 
 
         This function can raise a GnuCashBackendException. If it does,
         you don't need to cleanup and call end() and destroy(), that is handled
         for you, and the exception is raised.
         """
-        GnuCashCoreClass.__init__(self)
+        GnuCashCoreClass.__init__(self, Book())
         if book_uri is not None:
             try:
                 self.begin(book_uri, ignore_lock, is_new, force_new)
@@ -117,6 +141,15 @@ class Session(GnuCashCoreClass):
                 self.destroy()
                 raise
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        # Roll back changes on exception by not calling save. Only works for XMl backend.
+        if not exc_type:
+            self.save()
+        self.end()
+
     def raise_backend_errors(self, called_function="qof_session function"):
         """Raises a GnuCashBackendException if there are outstanding
         QOF_BACKEND errors.
@@ -239,7 +272,7 @@ class Book(GnuCashCoreClass):
 
     def InvoiceNextID(self, customer):
       ''' Return the next invoice ID.
-      This works but I'm not entirely happy with it.  FIX ME'''
+      '''
       from gnucash.gnucash_core_c import gncInvoiceNextID
       return gncInvoiceNextID(self.get_instance(),customer.GetEndOwner().get_instance()[1])
 
@@ -350,7 +383,7 @@ class GncPrice(GnuCashCoreClass):
       commodity with respect to another commodity.
       For example, a given price might represent the value of LNUX in USD on 2001-02-03.
 
-      See also http://code.gnucash.org/docs/head/group__Price.html
+      See also https://code.gnucash.org/docs/head/group__Price.html
     '''
     _new_instance = 'gnc_price_create'
 GncPrice.add_methods_with_prefix('gnc_price_')
@@ -369,7 +402,7 @@ class GncPriceDB(GnuCashCoreClass):
     Every QofBook contains a GNCPriceDB, accessible via gnc_pricedb_get_db.
 
     Definition in file gnc-pricedb.h.
-    See also http://code.gnucash.org/docs/head/gnc-pricedb_8h.html
+    See also https://code.gnucash.org/docs/head/gnc-pricedb_8h.html
     '''
 
 GncPriceDB.add_methods_with_prefix('gnc_pricedb_')
@@ -434,13 +467,26 @@ class Transaction(GnuCashCoreClass):
         return self.do_lookup_create_oo_instance(
             gncInvoiceGetInvoiceFromTxn, Transaction )
 
+    def __eq__(self, other):
+        return self.Equal(other, True, False, False, False)
+
 def decorate_monetary_list_returning_function(orig_function):
-    def new_function(self):
+    def new_function(self, *args):
+        """decorate function that returns list of gnc_monetary to return tuples of GncCommodity and GncNumeric
+
+        Args:
+            *args: Variable length argument list. Will get passed to orig_function
+
+        Returns:
+            array of tuples: (GncCommodity, GncNumeric)
+
+        ToDo:
+            Maybe this function should better reside in module function_class (?)"""
         # warning, item.commodity has been shown to be None
         # when the transaction doesn't have a currency
         return [(GncCommodity(instance=item.commodity),
                  GncNumeric(instance=item.value))
-                for item in orig_function(self) ]
+                for item in orig_function(self, *args) ]
     return new_function
 
 class Split(GnuCashCoreClass):
@@ -451,6 +497,9 @@ class Split(GnuCashCoreClass):
     """
     _new_instance = 'xaccMallocSplit'
 
+    def __eq__(self, other):
+        return self.Equal(other, True, False, False)
+
 class Account(GnuCashCoreClass):
     """A GnuCash Account.
 
@@ -609,7 +658,7 @@ methods_return_instance(GncLot, gnclot_dict)
 
 # Transaction
 Transaction.add_methods_with_prefix('xaccTrans')
-Transaction.add_method('gncTransGetGUID', 'GetGUID');
+Transaction.add_method('gncTransGetGUID', 'GetGUID')
 
 Transaction.add_method('xaccTransGetDescription', 'GetDescription')
 Transaction.add_method('xaccTransDestroy', 'Destroy')
@@ -638,7 +687,7 @@ Transaction.decorate_functions(
 
 # Split
 Split.add_methods_with_prefix('xaccSplit')
-Split.add_method('gncSplitGetGUID', 'GetGUID');
+Split.add_method('gncSplitGetGUID', 'GetGUID')
 Split.add_method('xaccSplitDestroy', 'Destroy')
 
 split_dict =    {
@@ -667,7 +716,7 @@ Split.parent = property( Split.GetParent, Split.SetParent )
 # Account
 Account.add_methods_with_prefix('xaccAccount')
 Account.add_methods_with_prefix('gnc_account_')
-Account.add_method('gncAccountGetGUID', 'GetGUID');
+Account.add_method('gncAccountGetGUID', 'GetGUID')
 Account.add_method('xaccAccountGetPlaceholder', 'GetPlaceholder')
 
 account_dict =  {
@@ -802,7 +851,8 @@ class QueryDatePredicate(GnuCashCoreClass):
     pass
 
 QueryDatePredicate.add_constructor_and_methods_with_prefix(
-    'qof_query_', 'date_predicate')
+    'qof_query_', 'date_predicate', exclude=["qof_query_date_predicate_get_date"])
+QueryDatePredicate.add_method('qof_query_date_predicate_get_date', 'get_date')
 
 class QueryGuidPredicate(GnuCashCoreClass):
     pass
