@@ -77,6 +77,7 @@
 #include "gnc-ui-util.h"
 #include "gnc-component-manager.h"
 #include "dialog-preferences.h"
+#include "dialog-assoc-utils.h"
 
 #define DIALOG_PREFERENCES_CM_CLASS "dialog-newpreferences"
 #define GNC_PREFS_GROUP             "dialogs.preferences"
@@ -90,6 +91,7 @@ static QofLogModule log_module = GNC_MOD_PREFS;
 void gnc_preferences_response_cb(GtkDialog *dialog, gint response, GtkDialog *unused);
 void gnc_account_separator_pref_changed_cb (GtkEntry *entry, GtkWidget *dialog);
 gboolean gnc_account_separator_validate_cb (GtkEntry *entry, GdkEvent *event, GtkWidget *dialog);
+void gnc_save_on_close_expires_cb (GtkToggleButton *button, GtkWidget *dialog);
 
 /** This data structure holds the information for a single addition to
  *  the preferences dialog. */
@@ -193,13 +195,25 @@ gnc_account_separator_validate_cb (GtkEntry *entry, GdkEvent *event, GtkWidget *
 
     if (conflict_msg)
     {
-        gnc_warning_dialog(dialog, "%s", conflict_msg);
+        gnc_warning_dialog (GTK_WINDOW (dialog), "%s", conflict_msg);
         g_free ( conflict_msg );
     }
     g_free (separator);
     return FALSE;
 }
 
+/** Called when the save-on-close checkbutton is toggled.
+ * @internal
+ * @param button the toggle button.
+ * @param dialog the prefs dialog.
+ */
+void
+gnc_save_on_close_expires_cb (GtkToggleButton *button, GtkWidget *dialog)
+{
+    GtkWidget *spinner = g_object_get_data (G_OBJECT (dialog),
+                                            "save_on_close_wait_time");
+    gtk_widget_set_sensitive(spinner, gtk_toggle_button_get_active(button));
+}
 
 /** This function compares two add-ins to see if they specify the same
  *  tab name.
@@ -548,7 +562,7 @@ gnc_preferences_build_page (gpointer data,
     GtkWidget *dialog, *existing_content, *new_content, *label;
     GtkNotebook *notebook;
     addition *add_in;
-    struct copy_data copydata;
+    struct copy_data copydata = {NULL, NULL, 0, 0};
     gchar **widgetname;
     gint i;
 
@@ -578,7 +592,7 @@ gnc_preferences_build_page (gpointer data,
     gnc_prefs_build_widget_table(builder, dialog);
 
     /* Connect the signals in this glade file. The dialog is passed in
-     * so the the callback can find "interesting" widgets from other
+     * so the callback can find "interesting" widgets from other
      * glade files if necessary (via the GPREFS_WIDGET_HASH hash table). */
     gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, dialog);
 
@@ -736,15 +750,29 @@ file_chooser_selected_cb (GtkFileChooser *fc, gpointer user_data)
 {
     GtkImage    *image = g_object_get_data (G_OBJECT(fc), "path_head_error");
     const gchar *group = g_object_get_data (G_OBJECT(fc), "group");
-    const gchar *pref = g_object_get_data (G_OBJECT(fc), "pref");
-    gchar       *folder = gtk_file_chooser_get_uri (fc);
+    const gchar  *pref = g_object_get_data (G_OBJECT(fc), "pref");
+    gchar        *folder_uri = gtk_file_chooser_get_uri (fc);
+    gchar *old_path_head_uri = gnc_assoc_get_path_head ();
+
+    // make sure path_head ends with a trailing '/', 3.5 onwards
+    if (!g_str_has_suffix (folder_uri, "/"))
+    {
+        gchar *folder_with_slash = g_strconcat (folder_uri, "/", NULL);
+        g_free (folder_uri);
+        folder_uri = g_strdup (folder_with_slash);
+        g_free (folder_with_slash);
+    }
 
     gtk_widget_hide (GTK_WIDGET(image));
 
-    if (!gnc_prefs_set_string (group, pref, folder))
-        PINFO("Failed to save preference at %s, %s with %s", group, pref, folder);
-
-    g_free (folder);
+    if (!gnc_prefs_set_string (group, pref, folder_uri))
+        PINFO("Failed to save preference at %s, %s with %s", group, pref, folder_uri);
+    else
+        gnc_assoc_pref_path_head_changed (GTK_WINDOW(gtk_widget_get_toplevel (
+                                          GTK_WIDGET(fc))), old_path_head_uri);
+    
+    g_free (old_path_head_uri);
+    g_free (folder_uri);
 }
 
 /** Connect a GtkFileChooserButton widget to its stored value in the preferences database.
@@ -763,10 +791,10 @@ gnc_prefs_connect_file_chooser_button (GtkFileChooserButton *fcb, const gchar *b
     gchar *uri;
     gboolean folder_set = TRUE;
 
-    g_return_if_fail(GTK_FILE_CHOOSER_BUTTON(fcb));
+    g_return_if_fail (GTK_FILE_CHOOSER_BUTTON(fcb));
 
     if (boxname == NULL)
-        gnc_prefs_split_widget_name (gtk_buildable_get_name(GTK_BUILDABLE(fcb)), &group, &pref);
+        gnc_prefs_split_widget_name (gtk_buildable_get_name (GTK_BUILDABLE(fcb)), &group, &pref);
     else
         gnc_prefs_split_widget_name (boxname, &group, &pref);
 
@@ -774,7 +802,7 @@ gnc_prefs_connect_file_chooser_button (GtkFileChooserButton *fcb, const gchar *b
 
     PINFO("Uri is %s", uri);
 
-    if ((uri != NULL) && (g_strcmp0 (uri, "") != 0)) // default entry
+    if (uri && *uri) // default entry
     {
         gchar *path_head = g_filename_from_uri (uri, NULL, NULL);
 
@@ -787,21 +815,19 @@ gnc_prefs_connect_file_chooser_button (GtkFileChooserButton *fcb, const gchar *b
         g_free (path_head);
     }
 
-    image = g_object_get_data(G_OBJECT(fcb), "path_head_error");
+    image = g_object_get_data (G_OBJECT(fcb), "path_head_error");
 
     if (folder_set) // If current folder missing, display error and tt message
         gtk_widget_hide (GTK_WIDGET(image));
     else
     {
-        gchar *uri_u = g_uri_unescape_string (uri, NULL);
-        gchar *path_head = g_filename_from_uri (uri_u, NULL, NULL);
+        gchar *path_head = gnc_assoc_get_unescape_uri (NULL, uri, "file");
         gchar *ttip = g_strconcat (_("Path does not exist, "), path_head, NULL);
 
-        gtk_widget_set_tooltip_text(GTK_WIDGET(image), ttip);
+        gtk_widget_set_tooltip_text (GTK_WIDGET(image), ttip);
         gtk_widget_show (GTK_WIDGET(image));
 
         g_free (ttip);
-        g_free (uri_u);
         g_free (path_head);
     }
 
@@ -815,7 +841,7 @@ gnc_prefs_connect_file_chooser_button (GtkFileChooserButton *fcb, const gchar *b
     g_free (pref);
     g_free (uri);
 
-    gtk_widget_show_all(GTK_WIDGET(fcb));
+    gtk_widget_show_all (GTK_WIDGET(fcb));
 }
 
 /** Callback for a 'Clear' button for GtkFileChooserButton widget.
@@ -836,28 +862,40 @@ file_chooser_clear_cb (GtkButton *button, gpointer user_data)
     GtkWidget            *box;
     GtkWidget            *fcb_new;
     gchar                *boxname;
+    gchar                *old_path_head_uri = gnc_assoc_get_path_head ();
 
-    /* We need to distroy the GtkFileChooserButton and recreate as there
+    /* We need to destroy the GtkFileChooserButton and recreate as there
        does not seem to be away of resetting the folder path to NONE */
     box = gtk_widget_get_parent (GTK_WIDGET(fcb));
-    gtk_widget_destroy (GTK_WIDGET(fcb));
+    g_signal_handlers_disconnect_by_func (button, file_chooser_clear_cb, fcb);
 
     if (!gnc_prefs_set_string (group, pref, ""))
         PINFO("Failed to Clear preference at %s, %s", group, pref);
+    else
+        gnc_assoc_pref_path_head_changed (GTK_WINDOW(gtk_widget_get_toplevel (
+                                          GTK_WIDGET(fcb))), old_path_head_uri);
+
+    gtk_widget_destroy (GTK_WIDGET(fcb));
 
     fcb_new = gtk_file_chooser_button_new (_("Select a folder"),
                              GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
     g_object_set_data (G_OBJECT(fcb_new), "path_head_error", image);
+    g_object_set_data_full (G_OBJECT(fcb_new),"group", g_strdup (group), (GDestroyNotify) g_free);
+    g_object_set_data_full (G_OBJECT(fcb_new),"pref", g_strdup (pref), (GDestroyNotify) g_free);
 
-    gtk_box_pack_start (GTK_BOX (box), fcb_new, TRUE, TRUE, 0);
-    gtk_box_reorder_child (GTK_BOX (box),fcb_new, 0);
+    gtk_box_pack_start (GTK_BOX(box), fcb_new, TRUE, TRUE, 0);
+    gtk_box_reorder_child (GTK_BOX(box), fcb_new, 0);
     gtk_widget_show (fcb_new);
 
+    g_signal_connect (GTK_BUTTON(button), "clicked",
+                      G_CALLBACK(file_chooser_clear_cb), fcb_new);
+
     boxname = g_strconcat ("pref/", group, "/", pref, NULL);
 
     gnc_prefs_connect_file_chooser_button (GTK_FILE_CHOOSER_BUTTON(fcb_new), boxname);
     g_free (boxname);
+    g_free (old_path_head_uri);
 }
 
 /****************************************************************************/
@@ -1153,9 +1191,8 @@ gnc_prefs_connect_one (const gchar *name,
         GList* child = gtk_container_get_children(GTK_CONTAINER(widget));
         widget_child = child->data;
         g_list_free(child);
-        DEBUG("  %s - hbox", name);
-        DEBUG("Hbox widget type is %s and name is %s", gtk_widget_get_name(GTK_WIDGET(widget_child)), name);
-
+        DEBUG("  %s - box", name);
+        DEBUG("Box widget type is %s and name is %s", gtk_widget_get_name(GTK_WIDGET(widget_child)), name);
         if (GNC_IS_CURRENCY_EDIT(widget_child))
         {
             DEBUG("  %s - currency_edit", name);
@@ -1163,7 +1200,7 @@ gnc_prefs_connect_one (const gchar *name,
         }
         else if (GNC_IS_PERIOD_SELECT(widget_child))
         {
-            DEBUG("  %s - period_Select", name);
+            DEBUG("  %s - period_select", name);
             gnc_prefs_connect_period_select(GNC_PERIOD_SELECT(widget_child), name );
         }
         else if (GNC_IS_DATE_EDIT(widget_child))
@@ -1173,7 +1210,7 @@ gnc_prefs_connect_one (const gchar *name,
         }
         else if (GTK_FILE_CHOOSER_BUTTON(widget_child))
         {
-            DEBUG("  %s - file chooser buuton", name);
+            DEBUG("  %s - file chooser button", name);
             gnc_prefs_connect_file_chooser_button(GTK_FILE_CHOOSER_BUTTON(widget_child), name );
         }
     }
@@ -1197,10 +1234,10 @@ gnc_prefs_connect_one (const gchar *name,
  *  @return A pointer to the newly created dialog.
  */
 static GtkWidget *
-gnc_preferences_dialog_create(void)
+gnc_preferences_dialog_create(GtkWindow *parent)
 {
     GtkBuilder *builder;
-    GtkWidget *dialog, *notebook, *label, *image;
+    GtkWidget *dialog, *notebook, *label, *image, *spinner;
     GtkWidget *box, *date, *period, *currency, *fcb, *button;
     GHashTable *prefs_table;
     GDate* gdate = NULL;
@@ -1229,12 +1266,19 @@ gnc_preferences_dialog_create(void)
     gnc_builder_add_from_file (builder, "dialog-preferences.glade", "retain_days_adj");
     gnc_builder_add_from_file (builder, "dialog-preferences.glade", "tab_width_adj");
     gnc_builder_add_from_file (builder, "dialog-preferences.glade", "date_formats");
+    gnc_builder_add_from_file (builder, "dialog-preferences.glade", "atm_fee_adj");
+    gnc_builder_add_from_file (builder, "dialog-preferences.glade", "auto_add_adj");
+    gnc_builder_add_from_file (builder, "dialog-preferences.glade", "auto_clear_adj");
+    gnc_builder_add_from_file (builder, "dialog-preferences.glade", "match_adj");
     gnc_builder_add_from_file (builder, "dialog-preferences.glade", "gnucash_preferences_dialog");
 
     dialog = GTK_WIDGET(gtk_builder_get_object (builder, "gnucash_preferences_dialog"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dialog), "GncPreferenceDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dialog), "gnc-id-preferences");
+
+    /* parent */
+    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(parent));
 
 #ifndef REGISTER2_ENABLED
     /* Hide preferences that are related to register2 */
@@ -1258,6 +1302,9 @@ gnc_preferences_dialog_create(void)
     image = GTK_WIDGET(gtk_builder_get_object (builder, "separator_error"));
     g_object_set_data(G_OBJECT(dialog), "separator_error", image);
 
+    spinner = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general/save-on-close-wait-time"));
+    g_object_set_data(G_OBJECT(dialog), "save_on_close_wait_time", spinner);
+
     DEBUG("autoconnect");
     gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, dialog);
 
@@ -1273,8 +1320,8 @@ gnc_preferences_dialog_create(void)
     book = gnc_get_current_book();
     g_date_clear (&fy_end, 1);
     qof_instance_get (QOF_INSTANCE (book),
-		      "fy-end", &fy_end,
-		      NULL);
+              "fy-end", &fy_end,
+              NULL);
     box = GTK_WIDGET(gtk_builder_get_object (builder,
                      "pref/" GNC_PREFS_GROUP_ACCT_SUMMARY "/" GNC_PREF_START_PERIOD));
     period = gnc_period_select_new(TRUE);
@@ -1341,7 +1388,9 @@ gnc_preferences_dialog_create(void)
     gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 0);
 
     DEBUG("We have the following interesting widgets:");
+    gnc_prefs_block_all(); // Block All Registered callbacks
     g_hash_table_foreach(prefs_table, (GHFunc)gnc_prefs_connect_one, dialog);
+    gnc_prefs_unblock_all(); // UnBlock All Registered callbacks
     DEBUG("Done with interesting widgets.");
 
     /* Other stuff */
@@ -1352,6 +1401,7 @@ gnc_preferences_dialog_create(void)
     if (gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path))
             gtk_list_store_set (store, &iter, 1, buf, -1);
     g_date_free(gdate);
+    gtk_tree_path_free (path);
 
     locale_currency = gnc_locale_default_currency ();
     currency_name = gnc_commodity_get_printname(locale_currency);
@@ -1360,6 +1410,9 @@ gnc_preferences_dialog_create(void)
     label = GTK_WIDGET(gtk_builder_get_object (builder, "locale_currency2"));
     gtk_label_set_label(GTK_LABEL(label), currency_name);
 
+    button = GTK_WIDGET(gtk_builder_get_object (builder, "pref/general/save-on-close-expires"));
+    gnc_save_on_close_expires_cb (GTK_TOGGLE_BUTTON(button), dialog);
+
     g_object_unref(G_OBJECT(builder));
 
     LEAVE("dialog %p", dialog);
@@ -1425,7 +1478,7 @@ close_handler (gpointer user_data)
  *  preferences dialog already exists it will be raised to the top of
  *  the window stack instead of creating a new dialog. */
 void
-gnc_preferences_dialog (void)
+gnc_preferences_dialog (GtkWindow *parent)
 {
     GtkWidget *dialog;
 
@@ -1437,9 +1490,9 @@ gnc_preferences_dialog (void)
         return;
     }
 
-    dialog = gnc_preferences_dialog_create();
+    dialog = gnc_preferences_dialog_create(parent);
 
-    gnc_restore_window_size(GNC_PREFS_GROUP, GTK_WINDOW(dialog));
+    gnc_restore_window_size(GNC_PREFS_GROUP, GTK_WINDOW(dialog), parent);
     gtk_widget_show(dialog);
 
     gnc_register_gui_component(DIALOG_PREFERENCES_CM_CLASS,
