@@ -126,7 +126,7 @@ gnc_strtok_r (char *s, const char *delim, char **save_ptr)
 
     /* Scan leading delimiters.  */
     s += strspn (s, delim);
-    if (*s == '\0')
+    if (!s || *s == '\0')
         return NULL;
 
     /* Find the end of the token.  */
@@ -147,33 +147,24 @@ gnc_strtok_r (char *s, const char *delim, char **save_ptr)
 static void
 gnc_date_edit_popdown(GNCDateEdit *gde)
 {
-#if GTK_CHECK_VERSION(3,20,0)
     GdkSeat *seat;
-#else
-    GdkDeviceManager *device_manager;
-#endif
     GdkDevice *pointer;
+    GdkWindow *window;
 
     g_return_if_fail (GNC_IS_DATE_EDIT (gde));
 
     ENTER("gde %p", gde);
 
-#if GTK_CHECK_VERSION(3,20,0)
-    seat = gdk_display_get_default_seat (gdk_display_get_default());
+    window = gtk_widget_get_window (GTK_WIDGET(gde));
+
+    seat = gdk_display_get_default_seat (gdk_window_get_display (window));
     pointer = gdk_seat_get_pointer (seat);
-#else
-    device_manager = gdk_display_get_device_manager (gdk_display_get_default());
-    pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
 
     gtk_grab_remove (gde->cal_popup);
     gtk_widget_hide (gde->cal_popup);
+
     if (pointer)
-#if GTK_CHECK_VERSION(3,20,0)
         gdk_seat_ungrab (seat);
-#else
-        gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-#endif
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gde->date_button),
                                   FALSE);
@@ -184,13 +175,13 @@ gnc_date_edit_popdown(GNCDateEdit *gde)
 static void
 day_selected (GtkCalendar *calendar, GNCDateEdit *gde)
 {
-    Timespec t;
+    time64 t;
     guint year, month, day;
     gde->in_selected_handler = TRUE;
     gtk_calendar_get_date (calendar, &year, &month, &day);
     /* GtkCalendar returns a 0-based month */
-    t = gnc_dmy2timespec (day, month + 1, year);
-    gnc_date_edit_set_time_ts (gde, t);
+    t = gnc_dmy2time64 (day, month + 1, year);
+    gnc_date_edit_set_time (gde, t);
     gde->in_selected_handler = FALSE;
 }
 
@@ -265,39 +256,20 @@ popup_grab_on_window (GdkWindow *window,
                       GdkDevice *pointer,
                       guint32    activate_time)
 {
-
-#if GTK_CHECK_VERSION(3,20,0)
-    GdkDisplay *display = gdk_display_get_default ();
+    GdkDisplay *display = gdk_window_get_display (window);
     GdkSeat *seat = gdk_display_get_default_seat (display);
     GdkEvent *event = gtk_get_current_event ();
 
     if (keyboard && gdk_seat_grab (seat, window, GDK_SEAT_CAPABILITY_KEYBOARD, TRUE, NULL,
-                                   event, NULL, NULL) != GDK_GRAB_SUCCESS )
-#else
-    if (keyboard && gdk_device_grab (keyboard, window,
-                                     GDK_OWNERSHIP_WINDOW, TRUE,
-                                     GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK,
-                                     NULL, activate_time) != GDK_GRAB_SUCCESS)
-#endif
+                                   event, NULL, NULL) != GDK_GRAB_SUCCESS)
         return FALSE;
 
-#if GTK_CHECK_VERSION(3,20,0)
     if (pointer && gdk_seat_grab (seat, window, GDK_SEAT_CAPABILITY_POINTER, TRUE, NULL,
-                                  event, NULL, NULL) != GDK_GRAB_SUCCESS )
-#else
-    if (pointer && gdk_device_grab (pointer, window,
-                                    GDK_OWNERSHIP_WINDOW, TRUE,
-                                    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-                                    GDK_POINTER_MOTION_MASK,
-                                    NULL, activate_time) != GDK_GRAB_SUCCESS)
-#endif
+                                  event, NULL, NULL) != GDK_GRAB_SUCCESS)
     {
         if (keyboard)
-#if GTK_CHECK_VERSION(3,20,0)
             gdk_seat_ungrab (seat);
-#else
-            gdk_device_ungrab (keyboard, activate_time);
-#endif
+
         return FALSE;
     }
     return TRUE;
@@ -558,13 +530,13 @@ fill_time_combo (GtkWidget *widget, GNCDateEdit *gde)
 static void
 gnc_date_edit_set_time_internal (GNCDateEdit *gde, time64 the_time)
 {
-    char buffer [40];
+    char buffer [MAX_DATE_LENGTH + 1];
     struct tm *mytm = gnc_localtime (&the_time);
 
     g_return_if_fail(mytm != NULL);
 
     /* Update the date text. */
-    qof_print_date_dmy_buff(buffer, 40,
+    qof_print_date_dmy_buff(buffer, MAX_DATE_LENGTH,
                             mytm->tm_mday,
                             mytm->tm_mon + 1,
                             1900 + mytm->tm_year);
@@ -698,8 +670,8 @@ gnc_date_edit_init (GNCDateEdit *gde)
 {
     gtk_orientable_set_orientation (GTK_ORIENTABLE(gde), GTK_ORIENTATION_HORIZONTAL);
 
-    // Set the style context for this widget so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(gde), "GncDateEdit");
+    // Set the name for this widget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(gde), "gnc-id-date-edit");
 
     gde->disposed = FALSE;
     gde->popup_in_progress = FALSE;
@@ -809,12 +781,6 @@ gnc_date_edit_set_gdate (GNCDateEdit *gde, const GDate *date)
     gnc_date_edit_set_time(gde, t);
 }
 
-void
-gnc_date_edit_set_time_ts (GNCDateEdit *gde, Timespec the_time)
-{
-    gnc_date_edit_set_time (gde, the_time.tv_sec);
-}
-
 /**
  * gnc_date_edit_set_popup_range:
  * @gde: The GNCDateEdit widget
@@ -1033,13 +999,6 @@ gnc_date_edit_new (time64 the_time, int show_time, int use_24_format)
              | (use_24_format ? GNC_DATE_EDIT_24_HR : 0)));
 }
 
-GtkWidget *
-gnc_date_edit_new_ts (Timespec the_time, int show_time, int use_24_format)
-{
-    return gnc_date_edit_new (the_time.tv_sec, show_time, use_24_format);
-}
-
-
 /*
  * Create a new GncDateEdit widget from a glade file.  The widget
  * generated is set to today's date, and will not show a time as part
@@ -1193,16 +1152,6 @@ gnc_date_edit_get_gdate (GNCDateEdit *gde, GDate *date)
     gnc_gdate_set_time64 (date, t);
 }
 
-Timespec
-gnc_date_edit_get_date_ts (GNCDateEdit *gde)
-{
-    Timespec ts = { 0, 0 };
-
-    ts.tv_sec = gnc_date_edit_get_date (gde);
-
-    return ts;
-}
-
 /**
  * gnc_date_edit_get_date_end:
  * @gde: The GNCDateEdit widget
@@ -1224,16 +1173,6 @@ gnc_date_edit_get_date_end (GNCDateEdit *gde)
     return gnc_mktime (&tm);
 }
 
-Timespec
-gnc_date_edit_get_date_end_ts (GNCDateEdit *gde)
-{
-    Timespec ts = { 0, 0 };
-
-    ts.tv_sec = gnc_date_edit_get_date_end (gde);
-
-    return ts;
-}
-
 /**
  * gnc_date_edit_set_flags:
  * @gde: The date editor widget whose flags should be changed.
