@@ -129,7 +129,7 @@ gnc_tree_model_account_update_color (gpointer gsettings, gchar *key, gpointer us
     model = user_data;
     priv = GNC_TREE_MODEL_ACCOUNT_GET_PRIVATE(model);
 
-    // destroy/recreate the cached acount value hash to force update
+    // destroy/recreate the cached account value hash to force update
     g_hash_table_destroy (priv->account_values_hash);
     priv->account_values_hash = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                        g_free, g_free);
@@ -140,7 +140,7 @@ gnc_tree_model_account_update_color (gpointer gsettings, gchar *key, gpointer us
         g_free (priv->negative_color);
 
     if (use_red)
-        priv->negative_color = get_negative_color ();
+        priv->negative_color = gnc_get_negative_color ();
     else
         priv->negative_color = NULL;
 }
@@ -175,7 +175,7 @@ static void
 gnc_tree_model_account_init (GncTreeModelAccount *model)
 {
     GncTreeModelAccountPrivate *priv;
-    gboolean red;
+    gboolean use_red;
 
     ENTER("model %p", model);
     while (model->stamp == 0)
@@ -183,7 +183,7 @@ gnc_tree_model_account_init (GncTreeModelAccount *model)
         model->stamp = g_random_int ();
     }
 
-    red = gnc_prefs_get_bool (GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED);
+    use_red = gnc_prefs_get_bool (GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED);
 
     priv = GNC_TREE_MODEL_ACCOUNT_GET_PRIVATE(model);
     priv->book = NULL;
@@ -192,8 +192,8 @@ gnc_tree_model_account_init (GncTreeModelAccount *model)
     if (priv->negative_color)
         g_free (priv->negative_color);
 
-    if (red)
-        priv->negative_color = get_negative_color ();
+    if (use_red)
+        priv->negative_color = gnc_get_negative_color ();
     else
         priv->negative_color = NULL;
 
@@ -252,7 +252,7 @@ gnc_tree_model_account_dispose (GObject *object)
     if (priv->negative_color)
         g_free (priv->negative_color);
 
-    // destroy the cached acount values
+    // destroy the cached account values
     g_hash_table_destroy (priv->account_values_hash);
 
     gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED,
@@ -418,6 +418,7 @@ gnc_tree_model_account_get_column_type (GtkTreeModel *tree_model, int index)
     case GNC_TREE_MODEL_ACCOUNT_COL_COLOR_TOTAL_PERIOD:
         return G_TYPE_STRING;
 
+    case GNC_TREE_MODEL_ACCOUNT_COL_HIDDEN:
     case GNC_TREE_MODEL_ACCOUNT_COL_PLACEHOLDER:
         return G_TYPE_BOOLEAN;
 
@@ -599,7 +600,7 @@ gnc_tree_model_account_clear_cache (GncTreeModelAccount *model)
     {
         GncTreeModelAccountPrivate *priv = GNC_TREE_MODEL_ACCOUNT_GET_PRIVATE(model);
 
-        // destroy the cached acount values and recreate
+        // destroy the cached account values and recreate
         g_hash_table_destroy (priv->account_values_hash);
         priv->account_values_hash = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                            g_free, g_free);
@@ -944,6 +945,11 @@ gnc_tree_model_account_get_value (GtkTreeModel *tree_model,
         g_value_set_string (value, xaccAccountGetLastNum (account));
         break;
 
+    case GNC_TREE_MODEL_ACCOUNT_COL_HIDDEN:
+        g_value_init (value, G_TYPE_BOOLEAN);
+        g_value_set_boolean (value, xaccAccountGetHidden (account));
+        break;
+
     case GNC_TREE_MODEL_ACCOUNT_COL_PLACEHOLDER:
         g_value_init (value, G_TYPE_BOOLEAN);
         g_value_set_boolean (value, xaccAccountGetPlaceholder (account));
