@@ -415,8 +415,9 @@ gnc_employee_new_window (GtkWindow *parent,
     ew->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "employee_dialog"));
     gtk_window_set_transient_for (GTK_WINDOW(ew->dialog), parent);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(ew->dialog), "GncEmployeeDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(ew->dialog), "gnc-id-employee");
+    gnc_widget_style_context_add_class (GTK_WIDGET(ew->dialog), "gnc-class-employees");
 
     g_object_set_data (G_OBJECT (ew->dialog), "dialog_info", ew);
 
@@ -476,6 +477,7 @@ gnc_employee_new_window (GtkWindow *parent,
     edit = gnc_account_sel_new();
     acct_types = g_list_prepend(NULL, (gpointer)ACCT_TYPE_CREDIT);
     gnc_account_sel_set_acct_filters (GNC_ACCOUNT_SEL(edit), acct_types, NULL);
+    gnc_account_sel_set_hexpand (GNC_ACCOUNT_SEL(edit), TRUE);
     g_list_free (acct_types);
 
     ew->ccard_acct_sel = edit;
@@ -740,7 +742,7 @@ gnc_employee_search (GtkWindow *parent, GncEmployee *start, QofBook *book)
                                      buttons, NULL, new_employee_cb,
                                      sw, free_employee_cb,
                                      GNC_PREFS_GROUP_SEARCH, NULL,
-                                     "GncFindEmployeeDialog");
+                                     "gnc-class-employees");
 }
 
 GNCSearchWindow *
