@@ -1414,6 +1414,7 @@ format_read_general_info(const gchar *file,
 static void
 free_check_format(check_format_t *data)
 {
+    g_return_if_fail(data);
     g_free(data->guid);
     g_free(data->filename);
     g_free(data->title);
@@ -1476,7 +1477,7 @@ static void
 read_one_check_directory(PrintCheckDialog *pcd, GtkListStore *store,
                          const gchar *groupname, const gchar *dirname)
 {
-    check_format_t *format, *existing;
+    check_format_t *format = NULL, *existing;
     GDir *dir;
     const gchar *filename;
     GtkTreeIter iter;
@@ -1520,6 +1521,7 @@ read_one_check_directory(PrintCheckDialog *pcd, GtkListStore *store,
              format->group, format->filename);
             gtk_dialog_run(GTK_DIALOG(dialog));
             gtk_widget_destroy(dialog);
+            free_check_format (format);
         }
         else
         {
@@ -1649,8 +1651,8 @@ gnc_ui_print_check_dialog_create(GtkWidget *parent,
     pcd->builder = builder;
     pcd->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "print_check_dialog"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(pcd->dialog), "GncPrintCheckDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(pcd->dialog), "gnc-id-print-check");
 
     /* now pick out the relevant child widgets */
     pcd->format_combobox = GTK_WIDGET(gtk_builder_get_object (builder, "check_format_combobox"));
