@@ -29,6 +29,7 @@
 #include <glib/gi18n.h>
 #include <string.h>
 
+#include "dialog-assoc.h"
 #include "dialog-billterms.h"
 #include "dialog-customer.h"
 #include "dialog-employee.h"
@@ -113,6 +114,8 @@ static void gnc_plugin_business_cmd_employee_find_expense_voucher (GtkAction *ac
 static void gnc_plugin_business_cmd_employee_process_payment      (GtkAction *action,
         GncMainWindowActionData *data);
 
+static void gnc_plugin_business_cmd_assoc              (GtkAction *action,
+        GncMainWindowActionData *data);
 static void gnc_plugin_business_cmd_tax_tables         (GtkAction *action,
         GncMainWindowActionData *data);
 static void gnc_plugin_business_cmd_billing_terms      (GtkAction *action,
@@ -271,6 +274,11 @@ static GtkActionEntry gnc_plugin_actions [] =
     },
 
     /* Other menu items */
+    {
+        "BusinessAssocOpenAction", NULL, N_("Business _Associations"), NULL,
+        N_("View all Business Associations"),
+        G_CALLBACK (gnc_plugin_business_cmd_assoc)
+    },
     {
         "TaxTablesOpenAction", NULL, N_("Sales _Tax Table"), NULL,
         N_("View and edit the list of Sales Tax Tables (GST/VAT)"),
@@ -340,38 +348,10 @@ typedef struct GncPluginBusinessPrivate
 } GncPluginBusinessPrivate;
 
 #define GNC_PLUGIN_BUSINESS_GET_PRIVATE(o)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_PLUGIN_BUSINESS, GncPluginBusinessPrivate))
+   ((GncPluginBusinessPrivate*)g_type_instance_get_private((GTypeInstance*)o, GNC_TYPE_PLUGIN_BUSINESS))
 
 static GObjectClass *parent_class = NULL;
 
-GType
-gnc_plugin_business_get_type (void)
-{
-    static GType gnc_plugin_business_type = 0;
-
-    if (gnc_plugin_business_type == 0)
-    {
-        static const GTypeInfo our_info =
-        {
-            sizeof (GncPluginBusinessClass),
-            NULL,		/* base_init */
-            NULL,		/* base_finalize */
-            (GClassInitFunc) gnc_plugin_business_class_init,
-            NULL,		/* class_finalize */
-            NULL,		/* class_data */
-            sizeof (GncPluginBusiness),
-            0,		/* n_preallocs */
-            (GInstanceInitFunc) gnc_plugin_business_init
-        };
-
-        gnc_plugin_business_type = g_type_register_static (GNC_TYPE_PLUGIN,
-                                   "GncPluginBusiness",
-                                   &our_info, 0);
-    }
-
-    return gnc_plugin_business_type;
-}
-
 GncPlugin *
 gnc_plugin_business_new (void)
 {
@@ -388,6 +368,8 @@ gnc_plugin_business_new (void)
     return GNC_PLUGIN (plugin);
 }
 
+G_DEFINE_TYPE_WITH_PRIVATE(GncPluginBusiness, gnc_plugin_business, GNC_TYPE_PLUGIN)
+
 static void
 gnc_plugin_business_class_init (GncPluginBusinessClass *klass)
 {
@@ -409,8 +391,6 @@ gnc_plugin_business_class_init (GncPluginBusinessClass *klass)
     plugin_class->actions      = gnc_plugin_actions;
     plugin_class->n_actions    = gnc_plugin_n_actions;
     plugin_class->ui_filename  = PLUGIN_UI_FILENAME;
-
-    g_type_class_add_private(klass, sizeof(GncPluginBusinessPrivate));
 }
 
 static void
@@ -471,7 +451,7 @@ gnc_plugin_business_cmd_customer_new_customer (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_ui_customer_new (gnc_get_current_book());
+    gnc_ui_customer_new (GTK_WINDOW (mw->window), gnc_get_current_book ());
 }
 
 static void
@@ -488,7 +468,7 @@ gnc_plugin_business_cmd_customer_find_customer (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     customer = gncOwnerGetCustomer (priv->last_customer);
-    gnc_customer_search (customer, gnc_get_current_book());
+    gnc_customer_search (GTK_WINDOW (mw->window), customer, gnc_get_current_book ());
 }
 
 static void
@@ -504,7 +484,7 @@ gnc_plugin_business_cmd_customer_new_invoice (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     last_window = mw->window;
-    gnc_ui_invoice_new (priv->last_customer, gnc_get_current_book());
+    gnc_ui_invoice_new (GTK_WINDOW (mw->window), priv->last_customer, gnc_get_current_book ());
 }
 
 static void
@@ -520,7 +500,7 @@ gnc_plugin_business_cmd_customer_find_invoice (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     last_window = mw->window;
-    gnc_invoice_search (NULL, priv->last_customer, gnc_get_current_book());
+    gnc_invoice_search (GTK_WINDOW (mw->window), NULL, priv->last_customer, gnc_get_current_book ());
 }
 
 static void
@@ -535,7 +515,7 @@ gnc_plugin_business_cmd_customer_new_job (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_ui_job_new (priv->last_customer, gnc_get_current_book());
+    gnc_ui_job_new (GTK_WINDOW (mw->window), priv->last_customer, gnc_get_current_book ());
 }
 
 static void
@@ -550,7 +530,7 @@ gnc_plugin_business_cmd_customer_find_job (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_job_search (NULL, priv->last_customer, gnc_get_current_book());
+    gnc_job_search (GTK_WINDOW (mw->window), NULL, priv->last_customer, gnc_get_current_book ());
 }
 
 static void
@@ -565,7 +545,7 @@ gnc_plugin_business_cmd_customer_process_payment (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_ui_payment_new (priv->last_customer, gnc_get_current_book());
+    gnc_ui_payment_new (GTK_WINDOW (mw->window), priv->last_customer, gnc_get_current_book ());
 }
 
 static void
@@ -588,7 +568,7 @@ gnc_plugin_business_cmd_vendor_new_vendor (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_ui_vendor_new (gnc_get_current_book());
+    gnc_ui_vendor_new (GTK_WINDOW (mw->window), gnc_get_current_book ());
 }
 
 static void
@@ -605,7 +585,7 @@ gnc_plugin_business_cmd_vendor_find_vendor (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     vendor = gncOwnerGetVendor (priv->last_vendor);
-    gnc_vendor_search (vendor, gnc_get_current_book());
+    gnc_vendor_search (GTK_WINDOW (mw->window), vendor, gnc_get_current_book ());
 }
 
 static void
@@ -621,7 +601,7 @@ gnc_plugin_business_cmd_vendor_new_bill (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     last_window = mw->window;
-    gnc_ui_invoice_new (priv->last_vendor, gnc_get_current_book());
+    gnc_ui_invoice_new (GTK_WINDOW (mw->window), priv->last_vendor, gnc_get_current_book ());
 }
 
 static void
@@ -637,7 +617,7 @@ gnc_plugin_business_cmd_vendor_find_bill (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     last_window = mw->window;
-    gnc_invoice_search (NULL, priv->last_vendor, gnc_get_current_book());
+    gnc_invoice_search (GTK_WINDOW (mw->window), NULL, priv->last_vendor, gnc_get_current_book ());
 }
 
 static void
@@ -652,7 +632,7 @@ gnc_plugin_business_cmd_vendor_new_job (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_ui_job_new (priv->last_vendor, gnc_get_current_book());
+    gnc_ui_job_new (GTK_WINDOW (mw->window), priv->last_vendor, gnc_get_current_book ());
 }
 
 static void
@@ -667,7 +647,7 @@ gnc_plugin_business_cmd_vendor_find_job (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_job_search (NULL, priv->last_vendor, gnc_get_current_book());
+    gnc_job_search (GTK_WINDOW (mw->window), NULL, priv->last_vendor, gnc_get_current_book ());
 }
 
 static void
@@ -682,7 +662,7 @@ gnc_plugin_business_cmd_vendor_process_payment (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_ui_payment_new (priv->last_vendor, gnc_get_current_book());
+    gnc_ui_payment_new (GTK_WINDOW (mw->window), priv->last_vendor, gnc_get_current_book ());
 }
 
 static void
@@ -705,7 +685,7 @@ gnc_plugin_business_cmd_employee_new_employee (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_ui_employee_new (gnc_get_current_book());
+    gnc_ui_employee_new (GTK_WINDOW (mw->window), gnc_get_current_book ());
 }
 
 static void
@@ -722,7 +702,7 @@ gnc_plugin_business_cmd_employee_find_employee (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     employee = gncOwnerGetEmployee (priv->last_employee);
-    gnc_employee_search (employee, gnc_get_current_book());
+    gnc_employee_search (GTK_WINDOW (mw->window), employee, gnc_get_current_book ());
 }
 
 static void
@@ -738,7 +718,7 @@ gnc_plugin_business_cmd_employee_new_expense_voucher (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     last_window = mw->window;
-    gnc_ui_invoice_new (priv->last_employee, gnc_get_current_book());
+    gnc_ui_invoice_new (GTK_WINDOW (mw->window), priv->last_employee, gnc_get_current_book ());
 }
 
 static void
@@ -754,7 +734,7 @@ gnc_plugin_business_cmd_employee_find_expense_voucher (GtkAction *action,
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
     last_window = mw->window;
-    gnc_invoice_search (NULL, priv->last_employee, gnc_get_current_book());
+    gnc_invoice_search (GTK_WINDOW (mw->window), NULL, priv->last_employee, gnc_get_current_book ());
 }
 
 static void
@@ -769,7 +749,17 @@ gnc_plugin_business_cmd_employee_process_payment (GtkAction *action,
 
     plugin = GNC_PLUGIN_BUSINESS (mw->data);
     priv = GNC_PLUGIN_BUSINESS_GET_PRIVATE (plugin);
-    gnc_ui_payment_new (priv->last_employee, gnc_get_current_book());
+    gnc_ui_payment_new (GTK_WINDOW (mw->window), priv->last_employee, gnc_get_current_book ());
+}
+
+static void
+gnc_plugin_business_cmd_assoc (GtkAction *action,
+                               GncMainWindowActionData *mw)
+{
+    g_return_if_fail (mw != NULL);
+    g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
+
+    gnc_assoc_business_dialog (GTK_WINDOW (mw->window));
 }
 
 static void
@@ -779,7 +769,7 @@ gnc_plugin_business_cmd_tax_tables (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_ui_tax_table_window_new (gnc_get_current_book());
+    gnc_ui_tax_table_window_new (GTK_WINDOW (mw->window), gnc_get_current_book());
 }
 
 static void
@@ -789,7 +779,7 @@ gnc_plugin_business_cmd_billing_terms (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_ui_billterms_window_new (gnc_get_current_book());
+    gnc_ui_billterms_window_new (GTK_WINDOW (mw->window), gnc_get_current_book());
 }
 
 
@@ -800,7 +790,7 @@ gnc_plugin_business_cmd_bills_due_reminder (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_invoice_remind_bills_due();
+    gnc_invoice_remind_bills_due (GTK_WINDOW (mw->window));
 }
 
 
@@ -811,7 +801,7 @@ gnc_plugin_business_cmd_invoices_due_reminder (GtkAction *action,
     g_return_if_fail (mw != NULL);
     g_return_if_fail (GNC_IS_PLUGIN_BUSINESS (mw->data));
 
-    gnc_invoice_remind_invoices_due();
+    gnc_invoice_remind_invoices_due (GTK_WINDOW (mw->window));
 }
 
 static void
@@ -821,7 +811,7 @@ gnc_plugin_business_cmd_test_search (GtkAction *action,
     gnc_search_dialog_test();
 }
 
-static void gnc_business_assign_payment (GtkWidget *parent,
+static void gnc_business_assign_payment (GtkWindow *parent,
         Transaction *trans,
         GncOwner *owner)
 {
@@ -883,7 +873,7 @@ static void gnc_plugin_business_cmd_assign_payment (GtkAction *action,
     else
         owner_p = plugin_business_priv->last_vendor;
 
-    gnc_business_assign_payment (gnc_plugin_page_get_window(plugin_page),
+    gnc_business_assign_payment (GTK_WINDOW (mw->window),
                                  trans, owner_p);
 }
 
@@ -910,6 +900,10 @@ gnc_plugin_business_update_menus (GncPluginPage *plugin_page)
     if (!plugin_page || !GNC_IS_PLUGIN_PAGE(plugin_page))
         return;
 
+    // Check that this is a main window and not embedded sx
+    if (!GNC_IS_MAIN_WINDOW(plugin_page->window))
+        return;
+
     is_txn_register = GNC_IS_PLUGIN_PAGE_REGISTER(plugin_page);
     window = GNC_MAIN_WINDOW(plugin_page->window);
     g_return_if_fail(GNC_IS_MAIN_WINDOW(window));
@@ -919,7 +913,7 @@ gnc_plugin_business_update_menus (GncPluginPage *plugin_page)
     if (is_txn_register)
     {
         Transaction *trans = gnc_plugin_page_register_get_current_txn (GNC_PLUGIN_PAGE_REGISTER(plugin_page));
-        if (xaccTransCountSplits(trans) > 0)
+        if (trans && xaccTransCountSplits(trans) > 0)
             is_bus_txn = (xaccTransGetFirstAPARAcctSplit(trans, TRUE) != NULL);
         is_bus_doc = (xaccTransGetTxnType (trans) == TXN_TYPE_INVOICE);
     }
@@ -953,18 +947,17 @@ static void
 gnc_plugin_business_cmd_test_init_data (GtkAction *action,
                                         GncMainWindowActionData *data)
 {
-    QofBook *book		= gnc_get_current_book();
-    GncCustomer *customer	= gncCustomerCreate(book);
-    GncAddress *address	= gncCustomerGetAddr(customer);
-    GncInvoice *invoice	= gncInvoiceCreate(book);
-    GncOwner *owner		= gncOwnerNew();
-    GncJob *job		= gncJobCreate(book);
-    Account *root		= gnc_book_get_root_account(book);
-    Account *inc_acct	= xaccMallocAccount(book);
-    Account *bank_acct	= xaccMallocAccount(book);
-    Account *tax_acct	= xaccMallocAccount(book);
-    Account *ar_acct	= xaccMallocAccount(book);
-    Timespec now;
+    QofBook *book           = gnc_get_current_book();
+    GncCustomer *customer   = gncCustomerCreate(book);
+    GncAddress *address     = gncCustomerGetAddr(customer);
+    GncInvoice *invoice     = gncInvoiceCreate(book);
+    GncOwner *owner         = gncOwnerNew();
+    GncJob *job             = gncJobCreate(book);
+    Account *root           = gnc_book_get_root_account(book);
+    Account *inc_acct       = xaccMallocAccount(book);
+    Account *bank_acct      = xaccMallocAccount(book);
+    Account *tax_acct       = xaccMallocAccount(book);
+    Account *ar_acct        = xaccMallocAccount(book);
 
     // Create Customer
     gncCustomerSetID(customer, "000001");
@@ -979,10 +972,9 @@ gnc_plugin_business_cmd_test_init_data (GtkAction *action,
     gncOwnerInitCustomer(owner, customer);
 
     // Create the Invoice
-    timespecFromTime64(&now, time(NULL));
     gncInvoiceSetID(invoice, "000012");
     gncInvoiceSetOwner(invoice, owner);
-    gncInvoiceSetDateOpened(invoice, now);
+    gncInvoiceSetDateOpened(invoice, gnc_time (NULL));
     gncInvoiceSetCurrency(invoice, gnc_default_currency());
 
     // Create the Job
@@ -1019,7 +1011,7 @@ gnc_plugin_business_cmd_test_init_data (GtkAction *action,
     gnc_account_append_child(root, tax_acct);
 
     // Launch the invoice editor
-    gnc_ui_invoice_edit(invoice);
+    gnc_ui_invoice_edit (GTK_WINDOW (data->window), invoice);
 }
 
 /* This is the list of actions which are switched inactive in a read-only book. */
@@ -1055,6 +1047,10 @@ static void update_inactive_actions(GncPluginPage *plugin_page)
     if (!plugin_page || !GNC_IS_PLUGIN_PAGE(plugin_page))
         return;
 
+    // Check that this is a main window and not embedded sx
+    if (!GNC_IS_MAIN_WINDOW(plugin_page->window))
+        return;
+
     window = GNC_MAIN_WINDOW(plugin_page->window);
     g_return_if_fail(GNC_IS_MAIN_WINDOW(window));
     action_group = gnc_main_window_get_action_group(window, PLUGIN_ACTIONS_NAME);
