@@ -27,7 +27,7 @@
 
 (use-modules (srfi srfi-13))
 (use-modules (ice-9 match))
-(use-modules (gnucash import-export string))
+(use-modules (gnucash string))
 
 (define (n- n) (gnc-numeric-neg n))
 (define (nsub a b) (gnc-numeric-sub a b 0 GNC-DENOM-LCD))
@@ -907,8 +907,8 @@
       (if (not (and far-acct-name near-acct-name))
           (if errorproc
               (errorproc "Transaction with no or only one associated account."))
-          (if (and (not (qif-xtn:mark (car xtns))))
-              (string=? (qif-xtn:from-acct (car xtns)) far-acct-name)
+          (if (and (not (qif-xtn:mark (car xtns)))
+                   (string=? (qif-xtn:from-acct (car xtns)) far-acct-name))
               (begin
                 (set! how
                       (qif-import:xtn-has-matches? (car xtns) near-acct-name
